==> core-js-0.7.1.tgz: package/src/es6.array.statics.js <==
require('./es6.iterators');
var $     = require('./$')
  , $def  = require('./$.def')
  , $iter = require('./$.iter');
function generic(A, B){
  // strange IE quirks mode bug -> use typeof instead of isFunction
  return typeof A == 'function' ? A : B;
}
$def($def.S + $def.F * $iter.DANGER_CLOSING, 'Array', {
  // 22.1.2.1 Array.from(arrayLike, mapfn = undefined, thisArg = undefined)
  from: function(arrayLike/*, mapfn = undefined, thisArg = undefined*/){
    var O       = Object($.assert.def(arrayLike))
      , mapfn   = arguments[1]
      , mapping = mapfn !== undefined
      , f       = mapping ? $.ctx(mapfn, arguments[2], 2) : undefined
      , index   = 0
      , length, result, step;
    if($iter.is(O)){
      result = new (generic(this, Array));
      $iter.exec(function(iterator){
        for(; !(step = iterator.next()).done; index++){
          result[index] = mapping ? f(step.value, index) : step.value;
        }
      }, $iter.get(O));
    } else {
      result = new (generic(this, Array))(length = $.toLength(O.length));
      for(; length > index; index++){
        result[index] = mapping ? f(O[index], index) : O[index];
      }
    }
    result.length = index;
    return result;
  }
});

$def($def.S, 'Array', {
  // 22.1.2.3 Array.of( ...items)
  of: function(/* ...args */){
    var index  = 0
      , length = arguments.length
      , result = new (generic(this, Array))(length);
    while(length > index)result[index] = arguments[index++];
    result.length = length;
    return result;
  }
});

require('./$.species')(Array);

==> core-js-0.7.2.tgz: package/src/es6.array.statics.js <==
require('./es6.iterators');
var $     = require('./$')
  , ctx   = require('./$.ctx')
  , $def  = require('./$.def')
  , $iter = require('./$.iter')
  , stepCall = $iter.stepCall
  , assertDefined = $.assertDefined;
function generic(A, B){
  // strange IE quirks mode bug -> use typeof instead of isFunction
  return typeof A == 'function' ? A : B;
}
$def($def.S + $def.F * $iter.DANGER_CLOSING, 'Array', {
  // 22.1.2.1 Array.from(arrayLike, mapfn = undefined, thisArg = undefined)
  from: function(arrayLike/*, mapfn = undefined, thisArg = undefined*/){
    var O       = Object(assertDefined(arrayLike))
      , mapfn   = arguments[1]
      , mapping = mapfn !== undefined
      , f       = mapping ? ctx(mapfn, arguments[2], 2) : undefined
      , index   = 0
      , length, result, step, iterator;
    if($iter.is(O)){
      iterator = $iter.get(O);
      result   = new (generic(this, Array));
      for(; !(step = iterator.next()).done; index++){
        result[index] = mapping ? stepCall(iterator, f, [step.value, index], true) : step.value;
      }
    } else {
      result = new (generic(this, Array))(length = $.toLength(O.length));
      for(; length > index; index++){
        result[index] = mapping ? f(O[index], index) : O[index];
      }
    }
    result.length = index;
    return result;
  }
});

$def($def.S, 'Array', {
  // 22.1.2.3 Array.of( ...items)
  of: function(/* ...args */){
    var index  = 0
      , length = arguments.length
      , result = new (generic(this, Array))(length);
    while(length > index)result[index] = arguments[index++];
    result.length = length;
    return result;
  }
});

require('./$.species')(Array);
